``numpy.searchsorted`` and ``numpy.sort`` behaviour updates
===========================================================

* ``numpy.searchsorted`` implementation updated to produce
  identical outputs to numpy for a wider set of use cases,
  including where the provided array `a` is in fact not
  properly sorted.

* ``numpy.searchsorted`` implementation bugfix for the case where
  side='right' and the provided array `a` contains NaN(s).

* ``numpy.searchsorted`` implementation extended to support complex
  inputs.

* ``numpy.sort`` (and ``array.sort``) implementation extended to
  support sorting of complex data.